/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:set ts=2 sw=2 sts=2 et cindent: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
#include "domstubs.idl"

[scriptable, uuid(7bd8c29f-8a76-453f-9373-79f820f2dc01)]
interface nsIDOMMediaError : nsISupports
{
  /* The download of the media resource was aborted by
     the user agent at the user's requet */
  const unsigned short MEDIA_ERR_ABORTED = 1;

  /* A network error of some description caused the 
     user agent to stop downloading the media resource */
  const unsigned short MEDIA_ERR_NETWORK = 2;

  /* An error of some description occurred while decoding 
     the media resource */
  const unsigned short MEDIA_ERR_DECODE  = 3;

  /* No suitable media resource could be found */
  const unsigned short MEDIA_ERR_SRC_NOT_SUPPORTED = 4;

  readonly attribute unsigned short code;
};
