/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

[scriptable, builtinclass, uuid(538d1085-517e-405a-a0f0-eb575cb0b8e5)]
interface nsIIndexedDatabaseManager : nsISupports
{
  /**
   * Defines indexedDB and IDBKeyRange with its static functions on aGlobal.
   *
   * This method might go away some time in the future, indexedDB and
   * IDBKeyRange should now be defined in all the spots (content windows,
   * chrome windows, xpcshell, JS modules, JS components, JS sandboxes,
   * ipcshell, bootstrapped extensions and Jetpack)
   *
   * @param aGlobal
   *        The global object, indexedDB and IDBKeyRange should be defined on.
   */
  [implicit_jscontext]
  void initWindowless(in jsval aGlobal);
};
